package cn.iocoder.yudao.module.jx.mapper;

import cn.iocoder.yudao.module.jx.domain.DriveContractTest;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

import java.util.List;


/**
 * 合同模板Mapper接口
 *
 * @author ruoyi
 * @date 2024-05-25
 */
@Mapper
public interface DriveContractTestMapper
{
    /**
     * 查询合同模板
     *
     * @param id 合同模板主键
     * @return 合同模板
     */
    public DriveContractTest selectDriveContractTestById(Long id);

    /**
     * 查询合同模板列表
     *
     * @param driveContractTest 合同模板
     * @return 合同模板集合
     */
    public IPage<DriveContractTest> selectDriveContractTestList(@Param("entity") DriveContractTest driveContractTest, Page<DriveContractTest> page);

    /**
     * 新增合同模板
     *
     * @param driveContractTest 合同模板
     * @return 结果
     */
    public int insertDriveContractTest(DriveContractTest driveContractTest);

    /**
     * 修改合同模板
     *
     * @param driveContractTest 合同模板
     * @return 结果
     */
    public int updateDriveContractTest(DriveContractTest driveContractTest);

    /**
     * 删除合同模板
     *
     * @param id 合同模板主键
     * @return 结果
     */
    public int deleteDriveContractTestById(Long id);

    /**
     * 批量删除合同模板
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteDriveContractTestByIds(Long[] ids);
}
